@@ -1,6 +1,7 @@
 import abc
 
-from validators import utils  # type: ignore
+from validators import *
+from validators import utils
 
 
 @utils.validator
@@ -13,6 +14,16 @@ def is_false(value):
     return value is False
 
 
+@utils.validator
+def does_end_with_slash(value):
+    return value.endswith('/')
+
+
+@utils.validator
+def does_not_end_with_slash(value):
+    return not does_end_with_slash(value)
+
+
 class Validator:
     @abc.abstractmethod
     def validate(self, value):
